@@ -57,7 +57,10 @@ class QuickbaseJSONClient:
             where = where.build()
 
         if kwargs.get('_test_', None):
-            return {'from': table, 'select': select, 'where': where}
+            return {
+                'from': table,
+                'select': select,
+                'where': where}
 
         if table == '':
             raise ValueError('Table cannot be blank')
@@ -66,7 +69,10 @@ class QuickbaseJSONClient:
             raise ValueError('Selection must contain at least one <int>')
 
         # create request body
-        body = {'from': table, 'select': select, 'where': where}
+        body = {
+            'from': table,
+            'select': select,
+            'where': where}
         # update with keyword args
         body.update(kwargs)
 
@@ -132,16 +138,28 @@ class QuickbaseJSONClient:
             open(f'{QUERY_CACHE}/{h}.json', 'w').write(json.dumps(data))
             return res
 
-    def insert_update_records(self, table: str, data: list):
+    def insert_update_records(self, table: str, data: list, legacy: bool = False):
         """
         Inerts or updates records in a given table.
         https://developer.quickbase.com/operation/upsert
         :param table: table to add records to
         :param data: list of dict of data, [{"6": {"value": 'example'}}] (do not include 3, record id to insert)
+        :param legacy: if true, will use legacy insert/update method
         :return: record id of created/updated records
         """
 
-        body = {'to': table, 'data': data}
+        def fix_null_values(json_data):
+            """Remove any fields with a null value."""
+            for record in json_data:
+                for key, value in list(record.items()):
+                    if value.get('value', None) is None:
+                        del record[key]
+            return json_data
+
+        body = {
+            'to': table,
+            'data': data if legacy else fix_null_values(data)
+        }
 
         if self.debug:
             print(f'QJAC : insert_update : body ---> \n{body}')
@@ -163,7 +181,9 @@ class QuickbaseJSONClient:
         """
 
         headers = self.headers
-        body = {'from': table, 'where': where}
+        body = {
+            'from': table,
+            'where': where}
 
         if self.debug:
             print(f'QJAC : delete_records : body ---> \n{body}')
@@ -211,8 +231,10 @@ class QuickbaseJSONClient:
         """
 
         headers = self.headers
-        params = {'appId': f'{app_id}'}
-        body = {'name': name}.update(kwargs)
+        params = {
+            'appId': f'{app_id}'}
+        body = {
+            'name': name}.update(kwargs)
 
         if self.debug:
             print(f'QJAC : create_table : body ---> \n{body}')
@@ -228,7 +250,8 @@ class QuickbaseJSONClient:
         """
 
         headers = self.headers
-        params = {'appId': f'{app_id}'}
+        params = {
+            'appId': f'{app_id}'}
         body = None
 
         if self.debug:
@@ -250,7 +273,8 @@ class QuickbaseJSONClient:
         """
 
         headers = self.headers
-        params = {'tableId': f'{table_id}'}
+        params = {
+            'tableId': f'{table_id}'}
         return requests.get('https://api.quickbase.com/v1/fields', params=params, headers=headers).json()
 
     """
@@ -279,7 +303,9 @@ class QuickbaseJSONClient:
         """
 
         headers = self.headers
-        params = {'tableId': f'{table}', 'fieldId': f'{fid}'}
+        params = {
+            'tableId': f'{table}',
+            'fieldId': f'{fid}'}
         fetch_url = "https://api.quickbase.com/v1/fields/" + str(fid) + "?tableId=" + table + "&includeFieldPerms=False"
         r = requests.get(fetch_url, headers=headers).json()
         if not 'message' in r:
@@ -297,9 +323,15 @@ class QuickbaseJSONClient:
         :param search_list: list of values to search for
         :return: json data of records {data: ..., fields: ...}
         """
-        response_for_return = {'data': [], 'fields': [],
-                               'metadata': {'numFields': 0, 'numRecords': 0, 'skip': 0, 'totalRecords': 0}}
-        list_of_searches = split_list_into_chunks(array=search_list, chunk_size=10)
+        response_for_return = {
+            'data': [],
+            'fields': [],
+            'metadata': {
+                'numFields': 0,
+                'numRecords': 0,
+                'skip': 0,
+                'totalRecords': 0}}
+        list_of_searches = split_list_into_chunks(array=search_list, chunk_size=100)
         for list_of_100 in list_of_searches:
             query = Where(fid=search_field, operator='EX', value=list_of_100).build(join='OR')
             r = self.query_records(table=table, select=select, where=query)
